changeset 731:ab752b2942ad draft

Updated several tests.
author Pavel Tisnovsky <ptisnovs@redhat.com>
date Wed, 10 Jun 2015 13:14:55 +0200
parents 7ff969ef2f75
children c043f06fd143
files ChangeLog src/org/gfxtest/testsuites/BitBltUsingBgColor.java
diffstat 2 files changed, 65 insertions(+), 60 deletions(-) [+]
line wrap: on
line diff
--- a/ChangeLog	Tue Jun 09 11:33:07 2015 +0200
+++ b/ChangeLog	Wed Jun 10 13:14:55 2015 +0200
@@ -1,3 +1,8 @@
+2015-06-09  Pavel Tisnovsky  <ptisnovs@redhat.com>
+
+	* src/org/gfxtest/testsuites/BitBltUsingBgColor.java:
+	Updated several tests.
+
 2015-06-09  Pavel Tisnovsky  <ptisnovs@redhat.com>
 
 	* src/org/gfxtest/testsuites/BitBltUsingBgColor.java:
--- a/src/org/gfxtest/testsuites/BitBltUsingBgColor.java	Tue Jun 09 11:33:07 2015 +0200
+++ b/src/org/gfxtest/testsuites/BitBltUsingBgColor.java	Wed Jun 10 13:14:55 2015 +0200
@@ -12961,7 +12961,7 @@
     }
 
     /**
      * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_BYTE_INDEXED.
      * Background color is set to Color.magenta.
      *
      * @param image
@@ -12970,13 +12970,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltDiagonalCheckerBufferedImageTypeByteIndexedBackgroundMagenta(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltDiagonalCheckerBufferedImageTypeByteIndexed(image, graphics2d, Color.magenta);
-    }
-
-    /**
-     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_BYTE_INDEXED.
+    public TestResult testBitBltGridBufferedImageTypeIntRGBbackgroundMagenta(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltGridBufferedImageTypeIntRGB(image, graphics2d, Color.magenta);
+    }
+
+    /**
+     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_INT_RGB}.
      * Background color is set to Color.yellow.
      *
      * @param image
@@ -12985,13 +12985,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltDiagonalCheckerBufferedImageTypeByteIndexedBackgroundYellow(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltDiagonalCheckerBufferedImageTypeByteIndexed(image, graphics2d, Color.yellow);
-    }
-
-    /**
-     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_BYTE_INDEXED.
+    public TestResult testBitBltGridBufferedImageTypeIntRGBbackgroundYellow(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltGridBufferedImageTypeIntRGB(image, graphics2d, Color.yellow);
+    }
+
+    /**
+     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_INT_RGB}.
      * Background color is set to Color.white.
      *
      * @param image
@@ -13000,13 +13000,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltDiagonalCheckerBufferedImageTypeByteIndexedBackgroundWhite(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltDiagonalCheckerBufferedImageTypeByteIndexed(image, graphics2d, Color.white);
-    }
-
-    /**
-     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_USHORT_555_RGB.
+    public TestResult testBitBltGridBufferedImageTypeIntRGBbackgroundWhite(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltGridBufferedImageTypeIntRGB(image, graphics2d, Color.white);
+    }
+
+    /**
+     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_INT_ARGB}.
      * Background color is set to Color.black.
      *
      * @param image
@@ -13015,13 +13015,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltDiagonalCheckerBufferedImageTypeUshort555RGBBackgroundBlack(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltDiagonalCheckerBufferedImageTypeUshort555RGB(image, graphics2d, Color.black);
-    }
-
-    /**
-     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_USHORT_555_RGB.
+    public TestResult testBitBltGridBufferedImageTypeIntARGBbackgroundBlack(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltGridBufferedImageTypeIntARGB(image, graphics2d, Color.black);
+    }
+
+    /**
+     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_INT_ARGB}.
      * Background color is set to Color.blue.
      *
      * @param image
@@ -13030,13 +13030,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltDiagonalCheckerBufferedImageTypeUshort555RGBBackgroundBlue(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltDiagonalCheckerBufferedImageTypeUshort555RGB(image, graphics2d, Color.blue);
-    }
-
-    /**
-     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_USHORT_555_RGB.
+    public TestResult testBitBltGridBufferedImageTypeIntARGBbackgroundBlue(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltGridBufferedImageTypeIntARGB(image, graphics2d, Color.blue);
+    }
+
+    /**
+     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_INT_ARGB}.
      * Background color is set to Color.green.
      *
      * @param image
@@ -13045,13 +13045,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltDiagonalCheckerBufferedImageTypeUshort555RGBBackgroundGreen(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltDiagonalCheckerBufferedImageTypeUshort555RGB(image, graphics2d, Color.green);
-    }
-
-    /**
-     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_USHORT_555_RGB.
+    public TestResult testBitBltGridBufferedImageTypeIntARGBbackgroundGreen(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltGridBufferedImageTypeIntARGB(image, graphics2d, Color.green);
+    }
+
+    /**
+     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_INT_ARGB}.
      * Background color is set to Color.cyan.
      *
      * @param image
@@ -13060,13 +13060,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltDiagonalCheckerBufferedImageTypeUshort555RGBBackgroundCyan(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltDiagonalCheckerBufferedImageTypeUshort555RGB(image, graphics2d, Color.cyan);
-    }
-
-    /**
-     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_USHORT_555_RGB.
+    public TestResult testBitBltGridBufferedImageTypeIntARGBbackgroundCyan(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltGridBufferedImageTypeIntARGB(image, graphics2d, Color.cyan);
+    }
+
+    /**
+     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_INT_ARGB}.
      * Background color is set to Color.red.
      *
      * @param image
@@ -13075,13 +13075,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltDiagonalCheckerBufferedImageTypeUshort555RGBBackgroundRed(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltDiagonalCheckerBufferedImageTypeUshort555RGB(image, graphics2d, Color.red);
-    }
-
-    /**
-     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_USHORT_555_RGB.
+    public TestResult testBitBltGridBufferedImageTypeIntARGBbackgroundRed(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltGridBufferedImageTypeIntARGB(image, graphics2d, Color.red);
+    }
+
+    /**
+     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_INT_ARGB}.
      * Background color is set to Color.magenta.
      *
      * @param image
@@ -13090,9 +13090,9 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltDiagonalCheckerBufferedImageTypeUshort555RGBBackgroundMagenta(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltDiagonalCheckerBufferedImageTypeUshort555RGB(image, graphics2d, Color.magenta);
+    public TestResult testBitBltGridBufferedImageTypeIntARGBbackgroundMagenta(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltGridBufferedImageTypeIntARGB(image, graphics2d, Color.magenta);
     }
 
     /**
@@ -12961,7 +12961,7 @@
 
     /**
-     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_BYTE_INDEXED.
+     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_INT_RGB}.
      * Background color is set to Color.magenta.
      *